@@ -3,6 +3,7 @@ from tensorflow import keras
 from tensorflow.keras import backend as K
 import os
 from keras_cv_attention_models.attention_layers import (
+    activation_by_name,
     anti_alias_downsample,
     batchnorm_with_activation,
     conv2d_no_bias,
@@ -163,15 +164,15 @@ def aot_block(
     # print(f">>>> {inputs.shape = }, {shortcut if shortcut is None else shortcut.shape = }, {deep.shape = }, {filters = }, {strides = }")
     if preact:  # ResNetV2
         deep = drop_block(deep, drop_rate)
-        return keras.layers.Add(name=name + "add")([shortcut, deep]) if shortcut is not None else deep  # if no shortcut
+        return keras.layers.Add(name=name + "output")([shortcut, deep]) if shortcut is not None else deep  # if no shortcut
     else:
         if not (use_3x3_kernel and bn_after_attn):
             deep = batchnorm_with_activation(deep, activation=None, zero_gamma=True, name=name + "3_")
         deep = drop_block(deep, drop_rate)
         out = keras.layers.Add(name=name + "add")([shortcut, deep]) if shortcut is not None else deep  # if no shortcut
         if use_block_output_activation:
-            out = keras.layers.Activation(activation, name=name + "out")(out)
-        return out
+            out = activation_by_name(out, activation, name=name + "out_")
+        return keras.layers.Activation('linear', name=name + "output")(out)  # Identity, Just need a name here
 
 
 def aot_stack(
@@ -257,7 +258,7 @@ def AotNet(
     drop_connect_rate=0,
     classifier_activation="softmax",
     output_num_features=0,
-    drop_rate=0,
+    dropout=0,
     model_name="aotnet",
     pretrained=None,
     kwargs=None,
@@ -297,7 +298,7 @@ def AotNet(
     if preact:  # resnetv2 like
         nn = batchnorm_with_activation(nn, activation=activation, zero_gamma=False, name="post_")
 
-    nn = output_block(nn, output_num_features, activation, num_classes, drop_rate=drop_rate, classifier_activation=classifier_activation)
+    nn = output_block(nn, output_num_features, activation, num_classes, drop_rate=dropout, classifier_activation=classifier_activation)
     model = keras.models.Model(inputs, nn, name=model_name)
     return model
 
