@@ -103,7 +103,7 @@ def cmt_block(inputs, num_heads=4, sr_ratio=1, expansion=4, activation="gelu", d
     ffn = layer_norm(attn_out, name=name + "ffn_")
     ffn = inverted_residual_feed_forward(ffn, expansion=expansion, activation=activation, name=name + "ffn_")
     ffn = drop_block(ffn, drop_rate=drop_rate)
-    ffn_out = keras.layers.Add(name=name + "ffn_out")([attn_out, ffn])
+    ffn_out = keras.layers.Add(name=name + "ffn_output")([attn_out, ffn])
 
     return ffn_out
 
@@ -130,7 +130,7 @@ def CMT(
     activation="gelu",
     drop_connect_rate=0,
     classifier_activation="softmax",
-    drop_rate=0,
+    dropout=0,
     pretrained=None,
     model_name="cmt",
     kwargs=None,
@@ -157,8 +157,8 @@ def CMT(
     if num_classes > 0:
         nn = keras.layers.GlobalAveragePooling2D(name="avg_pool")(nn)
         # nn = keras.layers.Dense(1280, name="post_dense")(nn)
-        if drop_rate > 0:
-            nn = keras.layers.Dropout(drop_rate)(nn)
+        if dropout > 0:
+            nn = keras.layers.Dropout(dropout)(nn)
         nn = keras.layers.Dense(num_classes, dtype="float32", activation=classifier_activation, name="predictions")(nn)
 
     model = keras.models.Model(inputs, nn, name=model_name)
