@@ -1,14 +1,48 @@
 import os
 import keras_cv_attention_models
+import tensorflow as tf
 from tensorflow import keras
 from keras_cv_attention_models.imagenet import callbacks, losses
 
+GLOBAL_STRATEGY = None
+
+def init_global_strategy(enable_float16=True, seed=0, TPU=False):
+    global GLOBAL_STRATEGY
+    if GLOBAL_STRATEGY is not None:
+        return GLOBAL_STRATEGY
+
+    gpus = tf.config.experimental.get_visible_devices("GPU")
+    for gpu in gpus:
+        tf.config.experimental.set_memory_growth(gpu, True)
+
+    if TPU:
+        resolver = tf.distribute.cluster_resolver.TPUClusterResolver(tpu="")
+        tf.config.experimental_connect_to_cluster(resolver)
+        # This is the TPU initialization code that has to be at the beginning.
+        tf.tpu.experimental.initialize_tpu_system(resolver)
+        print("All devices: ", tf.config.list_logical_devices("TPU"))
+        strategy = tf.distribute.TPUStrategy(resolver)
+    elif len(gpus) > 1:
+        strategy = tf.distribute.MirroredStrategy()
+    else:
+        strategy = tf.distribute.OneDeviceStrategy(device="/gpu:0")
+    GLOBAL_STRATEGY = strategy
+
+    if enable_float16:
+        policy = "mixed_bfloat16" if TPU else "mixed_float16"
+        keras.mixed_precision.set_global_policy(policy)
+
+    if seed is not None:
+        print(">>>> Set random seed:", seed)
+        tf.random.set_seed(seed)
+    return strategy
+
 
 def init_lr_scheduler(lr_base, lr_decay_steps, lr_min=1e-5, lr_decay_on_batch=False, lr_warmup=1e-4, lr_warmup_steps=0, lr_cooldown_steps=0):
     if isinstance(lr_decay_steps, list):
         constant_lr_sch = lambda epoch: callbacks.constant_scheduler(epoch, lr_base=lr_base, lr_decay_steps=lr_decay_steps, warmup_steps=lr_warmup_steps)
         lr_scheduler = keras.callbacks.LearningRateScheduler(constant_lr_sch)
-        lr_total_epochs = lr_decay_steps[-1] + lr_decay_steps[0]  # 120 for lr_decay_steps=[30, 60, 90], lr_warmup_steps=4
+        lr_total_epochs = lr_decay_steps[-1] + lr_cooldown_steps  # 120 for lr_decay_steps=[30, 60, 90], lr_warmup_steps=4, lr_cooldown_steps=30
     elif lr_decay_on_batch:
         lr_scheduler = callbacks.CosineLrScheduler(
             lr_base, lr_decay_steps, m_mul=0.5, t_mul=2.0, lr_min=lr_min, lr_warmup=lr_warmup, warmup_steps=lr_warmup_steps, cooldown_steps=lr_cooldown_steps
@@ -31,8 +65,8 @@ def init_optimizer(optimizer, lr_base, weight_decay):
     elif optimizer == "rmsprop":
         optimizer = keras.optimizers.RMSprop(learning_rate=lr_base, momentum=0.9)
     elif optimizer == "lamb":
-        bn_weights = ["bn/gamma", "bn/beta"]  # ["bn/moving_mean", "bn/moving_variance"] not in weights
-        optimizer = tfa.optimizers.LAMB(learning_rate=lr_base, weight_decay_rate=weight_decay, exclude_from_weight_decay=bn_weights, global_clipnorm=1.0)
+        norm_weights = ["bn/gamma", "bn/beta", "ln/gamma", "ln/beta"]  # ["bn/moving_mean", "bn/moving_variance"] not in weights
+        optimizer = tfa.optimizers.LAMB(learning_rate=lr_base, weight_decay_rate=weight_decay, exclude_from_weight_decay=norm_weights, global_clipnorm=1.0)
     elif optimizer == "adamw":
         optimizer = tfa.optimizers.AdamW(learning_rate=lr_base, weight_decay=lr_base * weight_decay)
     elif optimizer == "sgdw":
@@ -58,6 +92,10 @@ def init_loss(bce_threshold=1.0, label_smoothing=0):
 
 
 def init_model(model, input_shape=(224, 224, 3), num_classes=1000, pretrained=None, restore_path=None, **kwargs):
+    if isinstance(model, keras.models.Model):
+        print(">>> Got a keras.models.Model: {}, do nothing with it.".format(model.name))
+        return model
+
     print(">>> init_model kwargs:", kwargs)
     model = model.strip().split(".")
     if restore_path:
@@ -66,9 +104,6 @@ def init_model(model, input_shape=(224, 224, 3), num_classes=1000, pretrained=No
         print(">>>> Restore model from:", restore_path)
         model = keras.models.load_model(restore_path)
     else:
-        # model = cmt.CMTTiny(input_shape=input_shape, num_classes=num_classes, drop_connect_rate=0.2, drop_rate=0.2)
-        # model = keras.applications.ResNet50(weights=None, input_shape=input_shape)
-        # model = aotnet.AotNet50(num_classes=num_classes, input_shape=input_shape)
         if len(model) == 1:
             model = getattr(keras.applications, model[0])(classes=num_classes, weights=pretrained, input_shape=input_shape, **kwargs)
         else:
@@ -79,13 +114,14 @@ def init_model(model, input_shape=(224, 224, 3), num_classes=1000, pretrained=No
 
 
 def compile_model(model, optimizer, lr_base, weight_decay, bce_threshold, label_smoothing):
-    optimizer = optimizer.lower()
-    if optimizer == "sgd" and weight_decay > 0:
-        # Add L2 regularizer
-        from keras_cv_attention_models import model_surgery
+    if isinstance(optimizer, str):
+        optimizer = optimizer.lower()
+        if optimizer == "sgd" and weight_decay > 0:
+            # Add L2 regularizer
+            from keras_cv_attention_models import model_surgery
 
-        model = model_surgery.add_l2_regularizer_2_model(model, weight_decay=weight_decay, apply_to_batch_normal=False)
-    optimizer = init_optimizer(optimizer, lr_base, weight_decay)
+            model = model_surgery.add_l2_regularizer_2_model(model, weight_decay=weight_decay, apply_to_batch_normal=False)
+        optimizer = init_optimizer(optimizer, lr_base, weight_decay)
     loss = init_loss(bce_threshold, label_smoothing)
     print(">>>> Loss: {}, Optimizer: {}".format(loss.__class__.__name__, optimizer.__class__.__name__))
     model.compile(optimizer=optimizer, loss=loss, metrics=["acc"])
@@ -124,7 +160,7 @@ def train(compiled_model, epochs, train_dataset, test_dataset=None, initial_epoc
         wd_callback = callbacks.OptimizerWeightDecay(lr_base, wd_base, is_lr_on_batch=is_lr_on_batch)
         cur_callbacks.append(wd_callback)  # should be after lr_scheduler
 
-    compiled_model.fit(
+    hist = compiled_model.fit(
         train_dataset,
         epochs=epochs,
         verbose=1,
@@ -135,3 +171,4 @@ def train(compiled_model, epochs, train_dataset, test_dataset=None, initial_epoc
         use_multiprocessing=True,
         workers=8,
     )
+    return cur_callbacks[0].latest_save, hist
