@@ -3,12 +3,14 @@ from keras_cv_attention_models.model_surgery.model_surgery import (
     DropConnect,
     add_l2_regularizer_2_model,
     change_model_input_shape,
+    convert_gelu_and_extract_patches_for_tflite,
     convert_groups_conv2d_2_split_conv2d,
     convert_to_mixed_float16,
     convert_mixed_float16_to_float32,
     convert_to_fused_conv_bn_model,
     get_actual_survival_probabilities,
     get_actual_drop_connect_rates,
+    prepare_for_tflite,
     replace_ReLU,
     replace_add_with_drop_connect,
     replace_add_with_stochastic_depth,
